#include "config.h"

#include <iostream>
#include <string>
#include <pybind11/pybind11.h>
#include <pybind11/functional.h>
#include <pybind11/stl.h>
#include <c2py/c2py.hpp>

#include "module.hpp"
#include "wrappers.hpp"
#include "generated_functions.h"

#include "iTapTradeAPI.h"
#include "TapQuoteAPI.h"
#include "TapAPIError.h"
#include "iTapAPIError.h"
#include "custom/custom_wrappers.hpp"


void generate_vntap_variables(pybind11::module & parent)
{
    // APIYNFLAG_YES
    parent.attr("APIYNFLAG_YES") = APIYNFLAG_YES;
    // APIYNFLAG_NO
    parent.attr("APIYNFLAG_NO") = APIYNFLAG_NO;
    // APILOGLEVEL_NONE
    parent.attr("APILOGLEVEL_NONE") = APILOGLEVEL_NONE;
    // APILOGLEVEL_ERROR
    parent.attr("APILOGLEVEL_ERROR") = APILOGLEVEL_ERROR;
    // APILOGLEVEL_WARNING
    parent.attr("APILOGLEVEL_WARNING") = APILOGLEVEL_WARNING;
    // APILOGLEVEL_DEBUG
    parent.attr("APILOGLEVEL_DEBUG") = APILOGLEVEL_DEBUG;
    // TAPI_COMMODITY_TYPE_NONE
    parent.attr("TAPI_COMMODITY_TYPE_NONE") = TAPI_COMMODITY_TYPE_NONE;
    // TAPI_COMMODITY_TYPE_SPOT
    parent.attr("TAPI_COMMODITY_TYPE_SPOT") = TAPI_COMMODITY_TYPE_SPOT;
    // TAPI_COMMODITY_TYPE_FUTURES
    parent.attr("TAPI_COMMODITY_TYPE_FUTURES") = TAPI_COMMODITY_TYPE_FUTURES;
    // TAPI_COMMODITY_TYPE_OPTION
    parent.attr("TAPI_COMMODITY_TYPE_OPTION") = TAPI_COMMODITY_TYPE_OPTION;
    // TAPI_COMMODITY_TYPE_SPREAD_MONTH
    parent.attr("TAPI_COMMODITY_TYPE_SPREAD_MONTH") = TAPI_COMMODITY_TYPE_SPREAD_MONTH;
    // TAPI_COMMODITY_TYPE_SPREAD_COMMODITY
    parent.attr("TAPI_COMMODITY_TYPE_SPREAD_COMMODITY") = TAPI_COMMODITY_TYPE_SPREAD_COMMODITY;
    // TAPI_COMMODITY_TYPE_BUL
    parent.attr("TAPI_COMMODITY_TYPE_BUL") = TAPI_COMMODITY_TYPE_BUL;
    // TAPI_COMMODITY_TYPE_BER
    parent.attr("TAPI_COMMODITY_TYPE_BER") = TAPI_COMMODITY_TYPE_BER;
    // TAPI_COMMODITY_TYPE_STD
    parent.attr("TAPI_COMMODITY_TYPE_STD") = TAPI_COMMODITY_TYPE_STD;
    // TAPI_COMMODITY_TYPE_STG
    parent.attr("TAPI_COMMODITY_TYPE_STG") = TAPI_COMMODITY_TYPE_STG;
    // TAPI_COMMODITY_TYPE_PRT
    parent.attr("TAPI_COMMODITY_TYPE_PRT") = TAPI_COMMODITY_TYPE_PRT;
    // TAPI_COMMODITY_TYPE_BLT
    parent.attr("TAPI_COMMODITY_TYPE_BLT") = TAPI_COMMODITY_TYPE_BLT;
    // TAPI_COMMODITY_TYPE_BRT
    parent.attr("TAPI_COMMODITY_TYPE_BRT") = TAPI_COMMODITY_TYPE_BRT;
    // TAPI_COMMODITY_TYPE_DIRECTFOREX
    parent.attr("TAPI_COMMODITY_TYPE_DIRECTFOREX") = TAPI_COMMODITY_TYPE_DIRECTFOREX;
    // TAPI_COMMODITY_TYPE_INDIRECTFOREX
    parent.attr("TAPI_COMMODITY_TYPE_INDIRECTFOREX") = TAPI_COMMODITY_TYPE_INDIRECTFOREX;
    // TAPI_COMMODITY_TYPE_CROSSFOREX
    parent.attr("TAPI_COMMODITY_TYPE_CROSSFOREX") = TAPI_COMMODITY_TYPE_CROSSFOREX;
    // TAPI_COMMODITY_TYPE_INDEX
    parent.attr("TAPI_COMMODITY_TYPE_INDEX") = TAPI_COMMODITY_TYPE_INDEX;
    // TAPI_COMMODITY_TYPE_STOCK
    parent.attr("TAPI_COMMODITY_TYPE_STOCK") = TAPI_COMMODITY_TYPE_STOCK;
    // TAPI_COMMODITY_TYPE_SPOT_TRADINGDEFER
    parent.attr("TAPI_COMMODITY_TYPE_SPOT_TRADINGDEFER") = TAPI_COMMODITY_TYPE_SPOT_TRADINGDEFER;
    // TAPI_COMMODITY_TYPE_FUTURE_LOCK
    parent.attr("TAPI_COMMODITY_TYPE_FUTURE_LOCK") = TAPI_COMMODITY_TYPE_FUTURE_LOCK;
    // TAPI_COMMODITY_TYPE_EFP
    parent.attr("TAPI_COMMODITY_TYPE_EFP") = TAPI_COMMODITY_TYPE_EFP;
    // TAPI_CALLPUT_FLAG_CALL
    parent.attr("TAPI_CALLPUT_FLAG_CALL") = TAPI_CALLPUT_FLAG_CALL;
    // TAPI_CALLPUT_FLAG_PUT
    parent.attr("TAPI_CALLPUT_FLAG_PUT") = TAPI_CALLPUT_FLAG_PUT;
    // TAPI_CALLPUT_FLAG_NONE
    parent.attr("TAPI_CALLPUT_FLAG_NONE") = TAPI_CALLPUT_FLAG_NONE;
    // TAPIERROR_SUCCEED
    parent.attr("TAPIERROR_SUCCEED") = TAPIERROR_SUCCEED;
    // TAPIERROR_ConnectFail
    parent.attr("TAPIERROR_ConnectFail") = TAPIERROR_ConnectFail;
    // TAPIERROR_LinkAuthFail
    parent.attr("TAPIERROR_LinkAuthFail") = TAPIERROR_LinkAuthFail;
    // TAPIERROR_HostUnavailable
    parent.attr("TAPIERROR_HostUnavailable") = TAPIERROR_HostUnavailable;
    // TAPIERROR_SendDataError
    parent.attr("TAPIERROR_SendDataError") = TAPIERROR_SendDataError;
    // TAPIERROR_TestIDError
    parent.attr("TAPIERROR_TestIDError") = TAPIERROR_TestIDError;
    // TAPIERROR_NotReadyTestNetwork
    parent.attr("TAPIERROR_NotReadyTestNetwork") = TAPIERROR_NotReadyTestNetwork;
    // TAPIERROR_CurTestNotOver
    parent.attr("TAPIERROR_CurTestNotOver") = TAPIERROR_CurTestNotOver;
    // TAPIERROR_NOFrontAvailable
    parent.attr("TAPIERROR_NOFrontAvailable") = TAPIERROR_NOFrontAvailable;
    // TAPIERROR_DataPathAvaiable
    parent.attr("TAPIERROR_DataPathAvaiable") = TAPIERROR_DataPathAvaiable;
    // TAPIERROR_RepeatLogin
    parent.attr("TAPIERROR_RepeatLogin") = TAPIERROR_RepeatLogin;
    // TAPIERROR_InnerError
    parent.attr("TAPIERROR_InnerError") = TAPIERROR_InnerError;
    // TAPIERROR_LastReqNotFinish
    parent.attr("TAPIERROR_LastReqNotFinish") = TAPIERROR_LastReqNotFinish;
    // TAPIERROR_InputValueError
    parent.attr("TAPIERROR_InputValueError") = TAPIERROR_InputValueError;
    // TAPIERROR_AuthCode_Invalid
    parent.attr("TAPIERROR_AuthCode_Invalid") = TAPIERROR_AuthCode_Invalid;
    // TAPIERROR_AuthCode_Expired
    parent.attr("TAPIERROR_AuthCode_Expired") = TAPIERROR_AuthCode_Expired;
    // TAPIERROR_AuthCode_TypeNotMatch
    parent.attr("TAPIERROR_AuthCode_TypeNotMatch") = TAPIERROR_AuthCode_TypeNotMatch;
    // TAPIERROR_API_NotReady
    parent.attr("TAPIERROR_API_NotReady") = TAPIERROR_API_NotReady;
    // TAPIERROR_UDP_LISTEN_FAILED
    parent.attr("TAPIERROR_UDP_LISTEN_FAILED") = TAPIERROR_UDP_LISTEN_FAILED;
    // TAPIERROR_UDP_LISTENING
    parent.attr("TAPIERROR_UDP_LISTENING") = TAPIERROR_UDP_LISTENING;
    // TAPIERROR_NotImplemented
    parent.attr("TAPIERROR_NotImplemented") = TAPIERROR_NotImplemented;
    // TAPIERROR_CallOneTimeOnly
    parent.attr("TAPIERROR_CallOneTimeOnly") = TAPIERROR_CallOneTimeOnly;
    // TAPIERROR_Frequently
    parent.attr("TAPIERROR_Frequently") = TAPIERROR_Frequently;
    // TAPIERROR_INPUTERROR_NULL
    parent.attr("TAPIERROR_INPUTERROR_NULL") = TAPIERROR_INPUTERROR_NULL;
    // TAPIERROR_INPUTERROR_TAPIYNFLAG
    parent.attr("TAPIERROR_INPUTERROR_TAPIYNFLAG") = TAPIERROR_INPUTERROR_TAPIYNFLAG;
    // TAPIERROR_INPUTERROR_TAPILOGLEVEL
    parent.attr("TAPIERROR_INPUTERROR_TAPILOGLEVEL") = TAPIERROR_INPUTERROR_TAPILOGLEVEL;
    // TAPIERROR_INPUTERROR_TAPICommodityType
    parent.attr("TAPIERROR_INPUTERROR_TAPICommodityType") = TAPIERROR_INPUTERROR_TAPICommodityType;
    // TAPIERROR_INPUTERROR_TAPICallOrPutFlagType
    parent.attr("TAPIERROR_INPUTERROR_TAPICallOrPutFlagType") = TAPIERROR_INPUTERROR_TAPICallOrPutFlagType;
    // TAPIERROR_INPUTERROR_TAPIAccountType
    parent.attr("TAPIERROR_INPUTERROR_TAPIAccountType") = TAPIERROR_INPUTERROR_TAPIAccountType;
    // TAPIERROR_INPUTERROR_TAPIAccountState
    parent.attr("TAPIERROR_INPUTERROR_TAPIAccountState") = TAPIERROR_INPUTERROR_TAPIAccountState;
    // TAPIERROR_INPUTERROR_TAPIAccountFamilyType
    parent.attr("TAPIERROR_INPUTERROR_TAPIAccountFamilyType") = TAPIERROR_INPUTERROR_TAPIAccountFamilyType;
    // TAPIERROR_INPUTERROR_TAPIOrderTypeType
    parent.attr("TAPIERROR_INPUTERROR_TAPIOrderTypeType") = TAPIERROR_INPUTERROR_TAPIOrderTypeType;
    // TAPIERROR_INPUTERROR_TAPIOrderSourceType
    parent.attr("TAPIERROR_INPUTERROR_TAPIOrderSourceType") = TAPIERROR_INPUTERROR_TAPIOrderSourceType;
    // TAPIERROR_INPUTERROR_TAPITimeInForceType
    parent.attr("TAPIERROR_INPUTERROR_TAPITimeInForceType") = TAPIERROR_INPUTERROR_TAPITimeInForceType;
    // TAPIERROR_INPUTERROR_TAPISideType
    parent.attr("TAPIERROR_INPUTERROR_TAPISideType") = TAPIERROR_INPUTERROR_TAPISideType;
    // TAPIERROR_INPUTERROR_TAPIPositionEffectType
    parent.attr("TAPIERROR_INPUTERROR_TAPIPositionEffectType") = TAPIERROR_INPUTERROR_TAPIPositionEffectType;
    // TAPIERROR_INPUTERROR_TAPIHedgeFlagType
    parent.attr("TAPIERROR_INPUTERROR_TAPIHedgeFlagType") = TAPIERROR_INPUTERROR_TAPIHedgeFlagType;
    // TAPIERROR_INPUTERROR_TAPIOrderStateType
    parent.attr("TAPIERROR_INPUTERROR_TAPIOrderStateType") = TAPIERROR_INPUTERROR_TAPIOrderStateType;
    // TAPIERROR_INPUTERROR_TAPICalculateModeType
    parent.attr("TAPIERROR_INPUTERROR_TAPICalculateModeType") = TAPIERROR_INPUTERROR_TAPICalculateModeType;
    // TAPIERROR_INPUTERROR_TAPIMatchSourceType
    parent.attr("TAPIERROR_INPUTERROR_TAPIMatchSourceType") = TAPIERROR_INPUTERROR_TAPIMatchSourceType;
    // TAPIERROR_INPUTERROR_TAPIOpenCloseModeType
    parent.attr("TAPIERROR_INPUTERROR_TAPIOpenCloseModeType") = TAPIERROR_INPUTERROR_TAPIOpenCloseModeType;
    // TAPIERROR_INPUTERROR_TAPIFutureAlgType
    parent.attr("TAPIERROR_INPUTERROR_TAPIFutureAlgType") = TAPIERROR_INPUTERROR_TAPIFutureAlgType;
    // TAPIERROR_INPUTERROR_TAPIOptionAlgType
    parent.attr("TAPIERROR_INPUTERROR_TAPIOptionAlgType") = TAPIERROR_INPUTERROR_TAPIOptionAlgType;
    // TAPIERROR_INPUTERROR_TAPIBankAccountLWFlagType
    parent.attr("TAPIERROR_INPUTERROR_TAPIBankAccountLWFlagType") = TAPIERROR_INPUTERROR_TAPIBankAccountLWFlagType;
    // TAPIERROR_INPUTERROR_TAPIMarginCalculateModeType
    parent.attr("TAPIERROR_INPUTERROR_TAPIMarginCalculateModeType") = TAPIERROR_INPUTERROR_TAPIMarginCalculateModeType;
    // TAPIERROR_INPUTERROR_TAPIOptionMarginCalculateModeType
    parent.attr("TAPIERROR_INPUTERROR_TAPIOptionMarginCalculateModeType") = TAPIERROR_INPUTERROR_TAPIOptionMarginCalculateModeType;
    // TAPIERROR_INPUTERROR_TAPICmbDirectType
    parent.attr("TAPIERROR_INPUTERROR_TAPICmbDirectType") = TAPIERROR_INPUTERROR_TAPICmbDirectType;
    // TAPIERROR_INPUTERROR_TAPIDeliveryModeType
    parent.attr("TAPIERROR_INPUTERROR_TAPIDeliveryModeType") = TAPIERROR_INPUTERROR_TAPIDeliveryModeType;
    // TAPIERROR_INPUTERROR_TAPIContractTypeType
    parent.attr("TAPIERROR_INPUTERROR_TAPIContractTypeType") = TAPIERROR_INPUTERROR_TAPIContractTypeType;
    // TAPIERROR_INPUTERROR_TAPITacticsTypeType
    parent.attr("TAPIERROR_INPUTERROR_TAPITacticsTypeType") = TAPIERROR_INPUTERROR_TAPITacticsTypeType;
    // TAPIERROR_INPUTERROR_TAPIORDERACT
    parent.attr("TAPIERROR_INPUTERROR_TAPIORDERACT") = TAPIERROR_INPUTERROR_TAPIORDERACT;
    // TAPIERROR_INPUTERROR_TAPITriggerConditionType
    parent.attr("TAPIERROR_INPUTERROR_TAPITriggerConditionType") = TAPIERROR_INPUTERROR_TAPITriggerConditionType;
    // TAPIERROR_INPUTERROR_TAPITriggerPriceTypeType
    parent.attr("TAPIERROR_INPUTERROR_TAPITriggerPriceTypeType") = TAPIERROR_INPUTERROR_TAPITriggerPriceTypeType;
    // TAPIERROR_INPUTERROR_TAPITradingStateType
    parent.attr("TAPIERROR_INPUTERROR_TAPITradingStateType") = TAPIERROR_INPUTERROR_TAPITradingStateType;
    // TAPIERROR_INPUTERROR_TAPIMarketLevelType
    parent.attr("TAPIERROR_INPUTERROR_TAPIMarketLevelType") = TAPIERROR_INPUTERROR_TAPIMarketLevelType;
    // TAPIERROR_INPUTERROR_TAPIOrderQryTypeType
    parent.attr("TAPIERROR_INPUTERROR_TAPIOrderQryTypeType") = TAPIERROR_INPUTERROR_TAPIOrderQryTypeType;
    // TAPIERROR_DISCONNECT_CLOSE_INIT
    parent.attr("TAPIERROR_DISCONNECT_CLOSE_INIT") = TAPIERROR_DISCONNECT_CLOSE_INIT;
    // TAPIERROR_DISCONNECT_CLOSE_PASS
    parent.attr("TAPIERROR_DISCONNECT_CLOSE_PASS") = TAPIERROR_DISCONNECT_CLOSE_PASS;
    // TAPIERROR_DISCONNECT_READ_ERROR
    parent.attr("TAPIERROR_DISCONNECT_READ_ERROR") = TAPIERROR_DISCONNECT_READ_ERROR;
    // TAPIERROR_DISCONNECT_WRITE_ERROR
    parent.attr("TAPIERROR_DISCONNECT_WRITE_ERROR") = TAPIERROR_DISCONNECT_WRITE_ERROR;
    // TAPIERROR_DISCONNECT_BUF_FULL
    parent.attr("TAPIERROR_DISCONNECT_BUF_FULL") = TAPIERROR_DISCONNECT_BUF_FULL;
    // TAPIERROR_DISCONNECT_IOCP_ERROR
    parent.attr("TAPIERROR_DISCONNECT_IOCP_ERROR") = TAPIERROR_DISCONNECT_IOCP_ERROR;
    // TAPIERROR_DISCONNECT_PARSE_ERROR
    parent.attr("TAPIERROR_DISCONNECT_PARSE_ERROR") = TAPIERROR_DISCONNECT_PARSE_ERROR;
    // TAPIERROR_DISCONNECT_CONNECT_TIMEOUT
    parent.attr("TAPIERROR_DISCONNECT_CONNECT_TIMEOUT") = TAPIERROR_DISCONNECT_CONNECT_TIMEOUT;
    // TAPIERROR_DISCONNECT_INIT_ERROR
    parent.attr("TAPIERROR_DISCONNECT_INIT_ERROR") = TAPIERROR_DISCONNECT_INIT_ERROR;
    // TAPIERROR_DISCONNECT_HAS_CONNECTED
    parent.attr("TAPIERROR_DISCONNECT_HAS_CONNECTED") = TAPIERROR_DISCONNECT_HAS_CONNECTED;
    // TAPIERROR_DISCONNECT_HAS_EXIT
    parent.attr("TAPIERROR_DISCONNECT_HAS_EXIT") = TAPIERROR_DISCONNECT_HAS_EXIT;
    // TAPIERROR_DISCONNECT_TRY_LATER
    parent.attr("TAPIERROR_DISCONNECT_TRY_LATER") = TAPIERROR_DISCONNECT_TRY_LATER;
    // TAPIERROR_DISCONNECT_HEARTBEAT_FAILED
    parent.attr("TAPIERROR_DISCONNECT_HEARTBEAT_FAILED") = TAPIERROR_DISCONNECT_HEARTBEAT_FAILED;
    // TAPIERROR_LOGIN
    parent.attr("TAPIERROR_LOGIN") = TAPIERROR_LOGIN;
    // TAPIERROR_LOGIN_USER
    parent.attr("TAPIERROR_LOGIN_USER") = TAPIERROR_LOGIN_USER;
    // TAPIERROR_LOGIN_DDA
    parent.attr("TAPIERROR_LOGIN_DDA") = TAPIERROR_LOGIN_DDA;
    // TAPIERROR_LOGIN_LICENSE
    parent.attr("TAPIERROR_LOGIN_LICENSE") = TAPIERROR_LOGIN_LICENSE;
    // TAPIERROR_LOGIN_MODULE
    parent.attr("TAPIERROR_LOGIN_MODULE") = TAPIERROR_LOGIN_MODULE;
    // TAPIERROR_LOGIN_FORCE
    parent.attr("TAPIERROR_LOGIN_FORCE") = TAPIERROR_LOGIN_FORCE;
    // TAPIERROR_LOGIN_STATE
    parent.attr("TAPIERROR_LOGIN_STATE") = TAPIERROR_LOGIN_STATE;
    // TAPIERROR_LOGIN_PASS
    parent.attr("TAPIERROR_LOGIN_PASS") = TAPIERROR_LOGIN_PASS;
    // TAPIERROR_LOGIN_RIGHT
    parent.attr("TAPIERROR_LOGIN_RIGHT") = TAPIERROR_LOGIN_RIGHT;
    // TAPIERROR_LOGIN_COUNT
    parent.attr("TAPIERROR_LOGIN_COUNT") = TAPIERROR_LOGIN_COUNT;
    // TAPIERROR_LOGIN_NOTIN_SERVERFLAGUSRES
    parent.attr("TAPIERROR_LOGIN_NOTIN_SERVERFLAGUSRES") = TAPIERROR_LOGIN_NOTIN_SERVERFLAGUSRES;
    // TAPIERROR_LOGIN_USER_EXPIRED
    parent.attr("TAPIERROR_LOGIN_USER_EXPIRED") = TAPIERROR_LOGIN_USER_EXPIRED;
    // TAPIERROR_LOGIN_NO_ACCOUNT
    parent.attr("TAPIERROR_LOGIN_NO_ACCOUNT") = TAPIERROR_LOGIN_NO_ACCOUNT;
    // TAPIERROR_LOGIN_NO_JGT
    parent.attr("TAPIERROR_LOGIN_NO_JGT") = TAPIERROR_LOGIN_NO_JGT;
    // TAPIERROR_LOGIN_ERROR_TIMES
    parent.attr("TAPIERROR_LOGIN_ERROR_TIMES") = TAPIERROR_LOGIN_ERROR_TIMES;
    // TAPIERROR_LOGIN_ERROR_AUTHTYPE
    parent.attr("TAPIERROR_LOGIN_ERROR_AUTHTYPE") = TAPIERROR_LOGIN_ERROR_AUTHTYPE;
    // TAPIERROR_LOGIN_ERROR_AUTHEXPIRED
    parent.attr("TAPIERROR_LOGIN_ERROR_AUTHEXPIRED") = TAPIERROR_LOGIN_ERROR_AUTHEXPIRED;
    // TAPIERROR_LOGIN_ERROR_PASSWDEXPIRED
    parent.attr("TAPIERROR_LOGIN_ERROR_PASSWDEXPIRED") = TAPIERROR_LOGIN_ERROR_PASSWDEXPIRED;
    // TAPIERROR_USERINFO_QRY
    parent.attr("TAPIERROR_USERINFO_QRY") = TAPIERROR_USERINFO_QRY;
    // TAPIERROR_USERALLRIGHT_QRY
    parent.attr("TAPIERROR_USERALLRIGHT_QRY") = TAPIERROR_USERALLRIGHT_QRY;
    // TAPIERROR_USERALLACCOUNT_QRY
    parent.attr("TAPIERROR_USERALLACCOUNT_QRY") = TAPIERROR_USERALLACCOUNT_QRY;
    // TAPIERROR_USERPASSWORD_MOD
    parent.attr("TAPIERROR_USERPASSWORD_MOD") = TAPIERROR_USERPASSWORD_MOD;
    // TAPIERROR_USERPASSWORD_MOD_SOURCE
    parent.attr("TAPIERROR_USERPASSWORD_MOD_SOURCE") = TAPIERROR_USERPASSWORD_MOD_SOURCE;
    // TAPIERROR_USERPASSWORD_MOD_SAME
    parent.attr("TAPIERROR_USERPASSWORD_MOD_SAME") = TAPIERROR_USERPASSWORD_MOD_SAME;
    // TAPIERROR_USERPASSWORD_MOD_COMPLEXITY
    parent.attr("TAPIERROR_USERPASSWORD_MOD_COMPLEXITY") = TAPIERROR_USERPASSWORD_MOD_COMPLEXITY;
    // TAPIERROR_ACCOUNTINFO_QRY
    parent.attr("TAPIERROR_ACCOUNTINFO_QRY") = TAPIERROR_ACCOUNTINFO_QRY;
    // TAPIERROR_TRADENO_QRY
    parent.attr("TAPIERROR_TRADENO_QRY") = TAPIERROR_TRADENO_QRY;
    // TAPIERROR_CONTRACTINFO_QRY
    parent.attr("TAPIERROR_CONTRACTINFO_QRY") = TAPIERROR_CONTRACTINFO_QRY;
    // TAPIERROR_SPECIALOPTIONFUTURE_QRY
    parent.attr("TAPIERROR_SPECIALOPTIONFUTURE_QRY") = TAPIERROR_SPECIALOPTIONFUTURE_QRY;
    // TAPIERROR_COMMODITYORDERTYPE_QRY
    parent.attr("TAPIERROR_COMMODITYORDERTYPE_QRY") = TAPIERROR_COMMODITYORDERTYPE_QRY;
    // TAPIERROR_ORDERTIMEINFORCE_QRY
    parent.attr("TAPIERROR_ORDERTIMEINFORCE_QRY") = TAPIERROR_ORDERTIMEINFORCE_QRY;
    // TAPIERROR_USER_ORDER_FREQUENCE_QRY
    parent.attr("TAPIERROR_USER_ORDER_FREQUENCE_QRY") = TAPIERROR_USER_ORDER_FREQUENCE_QRY;
    // TAPIERROR_ORDERINSERT_ACCOUNT
    parent.attr("TAPIERROR_ORDERINSERT_ACCOUNT") = TAPIERROR_ORDERINSERT_ACCOUNT;
    // TAPIERROR_ORDERINSERT_ACCOUNT_STATE
    parent.attr("TAPIERROR_ORDERINSERT_ACCOUNT_STATE") = TAPIERROR_ORDERINSERT_ACCOUNT_STATE;
    // TAPIERROR_ORDERINSERT_SIDE_TRADE
    parent.attr("TAPIERROR_ORDERINSERT_SIDE_TRADE") = TAPIERROR_ORDERINSERT_SIDE_TRADE;
    // TAPIERROR_ORDERINSERT_OPTIONS_TRADE
    parent.attr("TAPIERROR_ORDERINSERT_OPTIONS_TRADE") = TAPIERROR_ORDERINSERT_OPTIONS_TRADE;
    // TAPIERROR_ORDERINSERT_COMMODITY_TRADE
    parent.attr("TAPIERROR_ORDERINSERT_COMMODITY_TRADE") = TAPIERROR_ORDERINSERT_COMMODITY_TRADE;
    // TAPIERROR_ORDERINSERT_OPEN_RIGHT
    parent.attr("TAPIERROR_ORDERINSERT_OPEN_RIGHT") = TAPIERROR_ORDERINSERT_OPEN_RIGHT;
    // TAPIERROR_ORDERINSERT_RISK_CHECK
    parent.attr("TAPIERROR_ORDERINSERT_RISK_CHECK") = TAPIERROR_ORDERINSERT_RISK_CHECK;
    // TAPIERROR_ORDERINSERT_CONTRACT
    parent.attr("TAPIERROR_ORDERINSERT_CONTRACT") = TAPIERROR_ORDERINSERT_CONTRACT;
    // TAPIERROR_ORDERINSERT_TRADEROUTE
    parent.attr("TAPIERROR_ORDERINSERT_TRADEROUTE") = TAPIERROR_ORDERINSERT_TRADEROUTE;
    // TAPIERROR_ORDERINSERT_POSITIONMAX
    parent.attr("TAPIERROR_ORDERINSERT_POSITIONMAX") = TAPIERROR_ORDERINSERT_POSITIONMAX;
    // TAPIERROR_ORDER_NOTRADE
    parent.attr("TAPIERROR_ORDER_NOTRADE") = TAPIERROR_ORDER_NOTRADE;
    // TAPIERROR_ORDER_CLOSE
    parent.attr("TAPIERROR_ORDER_CLOSE") = TAPIERROR_ORDER_CLOSE;
    // TAPIERROR_ORDERINSERT_NOTENOUGHFUND
    parent.attr("TAPIERROR_ORDERINSERT_NOTENOUGHFUND") = TAPIERROR_ORDERINSERT_NOTENOUGHFUND;
    // TAPIERROR_ORDERINSERT_ORDERTYPE
    parent.attr("TAPIERROR_ORDERINSERT_ORDERTYPE") = TAPIERROR_ORDERINSERT_ORDERTYPE;
    // TAPIERROR_ORDERINSERT_TIMEINFORCE
    parent.attr("TAPIERROR_ORDERINSERT_TIMEINFORCE") = TAPIERROR_ORDERINSERT_TIMEINFORCE;
    // TAPIERROR_ORDERINSERT_NO_TACTICS
    parent.attr("TAPIERROR_ORDERINSERT_NO_TACTICS") = TAPIERROR_ORDERINSERT_NO_TACTICS;
    // TAPIERROR_ORDERINSERT_POSITION_CANNOT_CLOSE
    parent.attr("TAPIERROR_ORDERINSERT_POSITION_CANNOT_CLOSE") = TAPIERROR_ORDERINSERT_POSITION_CANNOT_CLOSE;
    // TAPIERROR_ORDERINSERT_AUTOCHECK_FAIL
    parent.attr("TAPIERROR_ORDERINSERT_AUTOCHECK_FAIL") = TAPIERROR_ORDERINSERT_AUTOCHECK_FAIL;
    // TAPIERROR_ORDERINSERT_LME_NOTREADY
    parent.attr("TAPIERROR_ORDERINSERT_LME_NOTREADY") = TAPIERROR_ORDERINSERT_LME_NOTREADY;
    // TAPIERROR_ORDERINSERT_CLOSEMODE
    parent.attr("TAPIERROR_ORDERINSERT_CLOSEMODE") = TAPIERROR_ORDERINSERT_CLOSEMODE;
    // TAPIERROR_ORDERINSERT_PARENTNOTENOUGHFUND
    parent.attr("TAPIERROR_ORDERINSERT_PARENTNOTENOUGHFUND") = TAPIERROR_ORDERINSERT_PARENTNOTENOUGHFUND;
    // TAPIERROR_SWAP_CONTRACT
    parent.attr("TAPIERROR_SWAP_CONTRACT") = TAPIERROR_SWAP_CONTRACT;
    // TAPIERROR_USERNO_NOTHAS_ACCOUNT
    parent.attr("TAPIERROR_USERNO_NOTHAS_ACCOUNT") = TAPIERROR_USERNO_NOTHAS_ACCOUNT;
    // TAPIERROR_UPPERCHANNEL_BROKEN
    parent.attr("TAPIERROR_UPPERCHANNEL_BROKEN") = TAPIERROR_UPPERCHANNEL_BROKEN;
    // TAPIERROR_UPPERCHANNEL_NOT_EXIST
    parent.attr("TAPIERROR_UPPERCHANNEL_NOT_EXIST") = TAPIERROR_UPPERCHANNEL_NOT_EXIST;
    // TAPIERROR_ORDERDELETE_NOT_SYSNO
    parent.attr("TAPIERROR_ORDERDELETE_NOT_SYSNO") = TAPIERROR_ORDERDELETE_NOT_SYSNO;
    // TAPIERROR_ORDERDELETE_NOT_STATE
    parent.attr("TAPIERROR_ORDERDELETE_NOT_STATE") = TAPIERROR_ORDERDELETE_NOT_STATE;
    // TAPIERROR_ORDERACTIVE_NOT_STATE
    parent.attr("TAPIERROR_ORDERACTIVE_NOT_STATE") = TAPIERROR_ORDERACTIVE_NOT_STATE;
    // TAPIERROR_ORDERCHECK_NOT_STATE
    parent.attr("TAPIERROR_ORDERCHECK_NOT_STATE") = TAPIERROR_ORDERCHECK_NOT_STATE;
    // TAPIERROR_ORDERCHECK_FAIL
    parent.attr("TAPIERROR_ORDERCHECK_FAIL") = TAPIERROR_ORDERCHECK_FAIL;
    // TAPIERROR_ORDERMODIFY_NOT_STATE
    parent.attr("TAPIERROR_ORDERMODIFY_NOT_STATE") = TAPIERROR_ORDERMODIFY_NOT_STATE;
    // TAPIERROR_ORDERMODIFY_BACK_INPUT
    parent.attr("TAPIERROR_ORDERMODIFY_BACK_INPUT") = TAPIERROR_ORDERMODIFY_BACK_INPUT;
    // TAPIERROR_ORDERINSERT_FEE
    parent.attr("TAPIERROR_ORDERINSERT_FEE") = TAPIERROR_ORDERINSERT_FEE;
    // TAPIERROR_ORDERINSERT_MARGIN
    parent.attr("TAPIERROR_ORDERINSERT_MARGIN") = TAPIERROR_ORDERINSERT_MARGIN;
    // TAPIERROR_ORDER_NO_PERMIT
    parent.attr("TAPIERROR_ORDER_NO_PERMIT") = TAPIERROR_ORDER_NO_PERMIT;
    // TAPIERROR_RSPQUOTE_NO_PERMIT
    parent.attr("TAPIERROR_RSPQUOTE_NO_PERMIT") = TAPIERROR_RSPQUOTE_NO_PERMIT;
    // TAPIERROR_RSPQUOTE_CHILD_NO_PERMIT
    parent.attr("TAPIERROR_RSPQUOTE_CHILD_NO_PERMIT") = TAPIERROR_RSPQUOTE_CHILD_NO_PERMIT;
    // TAPIERROR_TRADENO_NOT_FIND
    parent.attr("TAPIERROR_TRADENO_NOT_FIND") = TAPIERROR_TRADENO_NOT_FIND;
    // TAPIERROR_ORDER_NO_CLOSE
    parent.attr("TAPIERROR_ORDER_NO_CLOSE") = TAPIERROR_ORDER_NO_CLOSE;
    // TAPIERROR_QRY_QUOTE_NO_PERMIT
    parent.attr("TAPIERROR_QRY_QUOTE_NO_PERMIT") = TAPIERROR_QRY_QUOTE_NO_PERMIT;
    // TAPIERROR_EXPIREDATE_NO_PERMIT
    parent.attr("TAPIERROR_EXPIREDATE_NO_PERMIT") = TAPIERROR_EXPIREDATE_NO_PERMIT;
    // TAPIERROR_CMB_NO_PERMIT
    parent.attr("TAPIERROR_CMB_NO_PERMIT") = TAPIERROR_CMB_NO_PERMIT;
    // TAPIERROR_ORDERSERVER_NO_PERMIT
    parent.attr("TAPIERROR_ORDERSERVER_NO_PERMIT") = TAPIERROR_ORDERSERVER_NO_PERMIT;
    // TAPIERROR_POSITION_CANNOT_EXEC_OR_ABANDON
    parent.attr("TAPIERROR_POSITION_CANNOT_EXEC_OR_ABANDON") = TAPIERROR_POSITION_CANNOT_EXEC_OR_ABANDON;
    // TAPIERROR_ORDERCHECK_NO_PERMIT
    parent.attr("TAPIERROR_ORDERCHECK_NO_PERMIT") = TAPIERROR_ORDERCHECK_NO_PERMIT;
    // TAPIERROR_ORDERMAXOPENVOL_NO_PERMIT
    parent.attr("TAPIERROR_ORDERMAXOPENVOL_NO_PERMIT") = TAPIERROR_ORDERMAXOPENVOL_NO_PERMIT;
    // TAPIERROR_ORDER_QTY_NO_PERMIT
    parent.attr("TAPIERROR_ORDER_QTY_NO_PERMIT") = TAPIERROR_ORDER_QTY_NO_PERMIT;
    // TAPIERROR_ORDER_APPLY_NO_PERMIT
    parent.attr("TAPIERROR_ORDER_APPLY_NO_PERMIT") = TAPIERROR_ORDER_APPLY_NO_PERMIT;
    // TAPIERROR_ORDER_FREQ_OVERRUN
    parent.attr("TAPIERROR_ORDER_FREQ_OVERRUN") = TAPIERROR_ORDER_FREQ_OVERRUN;
    // TAPIERROR_COMB_NO_SIDEORHEDGE
    parent.attr("TAPIERROR_COMB_NO_SIDEORHEDGE") = TAPIERROR_COMB_NO_SIDEORHEDGE;
    // TAPIERROR_ORDER_FREQUENCY
    parent.attr("TAPIERROR_ORDER_FREQUENCY") = TAPIERROR_ORDER_FREQUENCY;
    // TAPIERROR_ORDER_QUERYING
    parent.attr("TAPIERROR_ORDER_QUERYING") = TAPIERROR_ORDER_QUERYING;
    // TAPIERROR_SUBSCRIBEQUOTE_MAX
    parent.attr("TAPIERROR_SUBSCRIBEQUOTE_MAX") = TAPIERROR_SUBSCRIBEQUOTE_MAX;
    // TAPIERROR_SUBSCRIBEQUOTE_EXCHANGE_MAX
    parent.attr("TAPIERROR_SUBSCRIBEQUOTE_EXCHANGE_MAX") = TAPIERROR_SUBSCRIBEQUOTE_EXCHANGE_MAX;
    // TAPIERROR_SUBSCRIBEQUOTE_NO_RIGHT
    parent.attr("TAPIERROR_SUBSCRIBEQUOTE_NO_RIGHT") = TAPIERROR_SUBSCRIBEQUOTE_NO_RIGHT;
    // TAPIERROR_SUBSCRIBEQUOTE_NO_EXCHANGE_RIGHT
    parent.attr("TAPIERROR_SUBSCRIBEQUOTE_NO_EXCHANGE_RIGHT") = TAPIERROR_SUBSCRIBEQUOTE_NO_EXCHANGE_RIGHT;
    // TAPIERROR_SUBSCRIBEQUOTE_COMMODITY_NOT_EXIST
    parent.attr("TAPIERROR_SUBSCRIBEQUOTE_COMMODITY_NOT_EXIST") = TAPIERROR_SUBSCRIBEQUOTE_COMMODITY_NOT_EXIST;
    // TAPIERROR_SUBSCRIBEQUOTE_CONTRACT_MAY_NOT_EXIST
    parent.attr("TAPIERROR_SUBSCRIBEQUOTE_CONTRACT_MAY_NOT_EXIST") = TAPIERROR_SUBSCRIBEQUOTE_CONTRACT_MAY_NOT_EXIST;
    // TAPIERROR_QUOTEFRONT_UNKNOWN_PROTOCOL
    parent.attr("TAPIERROR_QUOTEFRONT_UNKNOWN_PROTOCOL") = TAPIERROR_QUOTEFRONT_UNKNOWN_PROTOCOL;
}
void generate_vntap_typedefs(pybind11::module & parent)
{
    
}
void generate_caster_(pybind11::object & parent)
{
    struct caster: c2py::caster{};
    auto c = c2py::caster::bind<caster>(parent, "caster"); 
    // TapAPIApplicationInfo
    c2py::caster::try_generate<TapAPIApplicationInfo>(c, "toTapAPIApplicationInfo");
    // TapAPICommodity
    c2py::caster::try_generate<TapAPICommodity>(c, "toTapAPICommodity");
    // TapAPIContract
    c2py::caster::try_generate<TapAPIContract>(c, "toTapAPIContract");
    // TapAPIExchangeInfo
    c2py::caster::try_generate<TapAPIExchangeInfo>(c, "toTapAPIExchangeInfo");
    // TapAPIChangePasswordReq
    c2py::caster::try_generate<TapAPIChangePasswordReq>(c, "toTapAPIChangePasswordReq");
    // TapAPIQuoteLoginAuth
    c2py::caster::try_generate<TapAPIQuoteLoginAuth>(c, "toTapAPIQuoteLoginAuth");
    // TapAPIQuotLoginRspInfo
    c2py::caster::try_generate<TapAPIQuotLoginRspInfo>(c, "toTapAPIQuotLoginRspInfo");
    // TapAPIQuoteCommodityInfo
    c2py::caster::try_generate<TapAPIQuoteCommodityInfo>(c, "toTapAPIQuoteCommodityInfo");
    // TapAPIQuoteContractInfo
    c2py::caster::try_generate<TapAPIQuoteContractInfo>(c, "toTapAPIQuoteContractInfo");
    // TapAPIQuoteWhole
    c2py::caster::try_generate<TapAPIQuoteWhole>(c, "toTapAPIQuoteWhole");
    // ITapQuoteAPINotify
    c2py::caster::try_generate<ITapQuoteAPINotify>(c, "toITapQuoteAPINotify");
    // ITapQuoteAPI
    c2py::caster::try_generate<ITapQuoteAPI>(c, "toITapQuoteAPI");
    // TAPISTR_10
    c2py::caster::try_generate<TAPISTR_10>(c, "toTAPISTR_10");
    // TAPISTR_20
    c2py::caster::try_generate<TAPISTR_20>(c, "toTAPISTR_20");
    // TAPISTR_30
    c2py::caster::try_generate<TAPISTR_30>(c, "toTAPISTR_30");
    // TAPISTR_40
    c2py::caster::try_generate<TAPISTR_40>(c, "toTAPISTR_40");
    // TAPISTR_50
    c2py::caster::try_generate<TAPISTR_50>(c, "toTAPISTR_50");
    // TAPISTR_70
    c2py::caster::try_generate<TAPISTR_70>(c, "toTAPISTR_70");
    // TAPISTR_100
    c2py::caster::try_generate<TAPISTR_100>(c, "toTAPISTR_100");
    // TAPISTR_300
    c2py::caster::try_generate<TAPISTR_300>(c, "toTAPISTR_300");
    // TAPISTR_500
    c2py::caster::try_generate<TAPISTR_500>(c, "toTAPISTR_500");
    // TAPISTR_2000
    c2py::caster::try_generate<TAPISTR_2000>(c, "toTAPISTR_2000");
    // TAPIAUTHCODE
    c2py::caster::try_generate<TAPIAUTHCODE>(c, "toTAPIAUTHCODE");
    // TAPICHAR
    c2py::caster::try_generate<TAPICHAR>(c, "toTAPICHAR");
    // TAPIINT32
    c2py::caster::try_generate<TAPIINT32>(c, "toTAPIINT32");
    // TAPIUINT32
    c2py::caster::try_generate<TAPIUINT32>(c, "toTAPIUINT32");
    // TAPIINT64
    c2py::caster::try_generate<TAPIINT64>(c, "toTAPIINT64");
    // TAPIUINT64
    c2py::caster::try_generate<TAPIUINT64>(c, "toTAPIUINT64");
    // TAPIUINT16
    c2py::caster::try_generate<TAPIUINT16>(c, "toTAPIUINT16");
    // TAPIUINT8
    c2py::caster::try_generate<TAPIUINT8>(c, "toTAPIUINT8");
    // TAPIREAL64
    c2py::caster::try_generate<TAPIREAL64>(c, "toTAPIREAL64");
    // TAPIYNFLAG
    c2py::caster::try_generate<TAPIYNFLAG>(c, "toTAPIYNFLAG");
    // TAPIDTSTAMP
    c2py::caster::try_generate<TAPIDTSTAMP>(c, "toTAPIDTSTAMP");
    // TAPIDATETIME
    c2py::caster::try_generate<TAPIDATETIME>(c, "toTAPIDATETIME");
    // TAPIDATE
    c2py::caster::try_generate<TAPIDATE>(c, "toTAPIDATE");
    // TAPITIME
    c2py::caster::try_generate<TAPITIME>(c, "toTAPITIME");
    // TAPILOGLEVEL
    c2py::caster::try_generate<TAPILOGLEVEL>(c, "toTAPILOGLEVEL");
    // TAPICommodityType
    c2py::caster::try_generate<TAPICommodityType>(c, "toTAPICommodityType");
    // TAPICallOrPutFlagType
    c2py::caster::try_generate<TAPICallOrPutFlagType>(c, "toTAPICallOrPutFlagType");
    // TAPIQPRICE
    c2py::caster::try_generate<TAPIQPRICE>(c, "toTAPIQPRICE");
    // TAPIQVOLUME
    c2py::caster::try_generate<TAPIQVOLUME>(c, "toTAPIQVOLUME");
    // TAPIQDIFF
    c2py::caster::try_generate<TAPIQDIFF>(c, "toTAPIQDIFF");
}
void generate_vntap_caster(pybind11::module & parent)
{
    generate_caster_(parent);
}
